import { createVNode as _createVNode } from "vue";
// Styles
import "./VBanner.sass"; // Composables

import { makeSheetProps, useSheet } from "../VSheet/VSheet.mjs"; // Utilities

import { defineComponent } from 'vue';
import makeProps from "../../util/makeProps.mjs";
export default defineComponent({
  name: 'VBanner',
  props: makeProps({
    avatar: String,
    icon: String,
    mobile: Boolean,
    singleLine: Boolean,
    sticky: Boolean,
    ...makeSheetProps()
  }),

  setup(props, {
    slots
  }) {
    const {
      sheetClasses,
      sheetStyles
    } = useSheet(props, 'v-banner');
    return () => {
      const hasThumbnail = !!props.avatar || !!props.icon || !!slots.thumbnail;
      return _createVNode(props.tag, {
        "class": ['v-banner', {
          'v-banner--has-thumbnail': hasThumbnail,
          'v-banner--is-mobile': props.mobile,
          'v-banner--single-line': props.singleLine,
          'v-banner--sticky': props.sticky
        }, sheetClasses.value],
        "style": sheetStyles.value,
        "role": "banner"
      }, {
        default: () => [_createVNode("div", {
          "class": "v-banner__sizer"
        }, [_createVNode("div", {
          "class": "v-banner__content"
        }, [hasThumbnail && _createVNode("div", {
          "class": "v-banner__thumbnail"
        }, [slots.thumbnail == null ? void 0 : slots.thumbnail(), props.avatar && _createVNode("img", {
          "class": "v-banner__avatar",
          "src": props.avatar,
          "alt": ""
        }, null, 8, ["src"]), props.icon && _createVNode("i", {
          "class": "v-banner__icon"
        }, [props.icon])]), _createVNode("div", {
          "class": "v-banner__text"
        }, [slots.default == null ? void 0 : slots.default()])]), slots.actions && _createVNode("div", {
          "class": "v-banner__actions"
        }, [slots.actions == null ? void 0 : slots.actions()])])],
        _: 1
      }, 8, ["class", "style"]);
    };
  }

});
//# sourceMappingURL=VBanner.mjs.map