import { createVNode as _createVNode } from "vue";
// Styles
import "./VBtn.sass"; // Composables

import { makeDensityProps, useDensity } from "../../composables/density.mjs";
import { makeSheetProps, useSheet } from "../VSheet/VSheet.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { useColor } from "../../composables/color.mjs"; // Directives

import { Ripple } from "../../directives/ripple/index.mjs"; // Components

import VIcon from "../VIcon/VIcon.mjs"; // Utilities

import { computed, defineComponent, withDirectives } from 'vue';
import makeProps from "../../util/makeProps.mjs";
import { useDirective } from "../../util/useDirective.mjs";
import { makeSizeProps, useSize } from "../../composables/size.mjs";
export default defineComponent({
  name: 'VBtn',
  props: makeProps({
    text: Boolean,
    flat: Boolean,
    plain: Boolean,
    icon: [Boolean, String],
    block: Boolean,
    color: {
      type: String,
      default: 'primary'
    },
    disabled: Boolean,
    ...makeSheetProps(),
    ...makeSizeProps(),
    ...makeDensityProps(),
    ...makeTagProps({
      tag: 'button'
    })
  }),

  setup(props, {
    slots
  }) {
    const {
      sheetClasses,
      sheetStyles
    } = useSheet(props, 'v-btn');
    const {
      sizeClasses
    } = useSize(props, 'v-btn');
    const {
      densityClasses
    } = useDensity(props, 'v-btn');
    const isContained = computed(() => {
      return !(props.text || props.plain || props.icon || props.outlined || props.border !== false);
    });
    const isElevated = computed(() => {
      return isContained.value && !(props.disabled || props.flat);
    });
    const {
      colorClasses,
      colorStyles
    } = useColor(computed(() => ({
      [isContained.value ? 'background' : 'text']: props.color
    })));
    return () => withDirectives(_createVNode(props.tag, {
      "type": "button",
      "class": ['v-btn', {
        'v-btn--contained': isContained.value,
        'v-btn--elevated': isElevated.value,
        'v-btn--icon': !!props.icon,
        'v-btn--plain': props.plain,
        'v-btn--block': props.block,
        'v-btn--disabled': props.disabled
      }, sheetClasses.value, sizeClasses.value, densityClasses.value, colorClasses.value],
      "style": [sheetStyles.value, colorStyles.value],
      "disabled": props.disabled
    }, {
      default: () => [_createVNode("span", {
        "class": "v-btn__overlay"
      }, null), typeof props.icon === 'boolean' ? slots.default == null ? void 0 : slots.default() : _createVNode(VIcon, {
        "icon": props.icon,
        "size": props.size
      }, null, 8, ["icon", "size"])],
      _: 1
    }, 8, ["class", "style", "disabled"]), [useDirective(Ripple, {
      value: !props.disabled,
      modifiers: {
        center: !!props.icon
      }
    })]);
  }

});
//# sourceMappingURL=VBtn.mjs.map