import { createVNode as _createVNode, resolveDirective as _resolveDirective } from "vue";
// Styles
import "./VSheet.sass"; // Composables

import { makeBorderProps, useBorder } from "../../composables/border.mjs";
import { makeBorderRadiusProps, useBorderRadius } from "../../composables/border-radius.mjs";
import { makeDimensionProps, useDimension } from "../../composables/dimensions.mjs";
import { makeElevationProps, useElevation } from "../../composables/elevation.mjs";
import { makePositionProps, usePosition } from "../../composables/position.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { useTheme } from "../../composables/theme.mjs"; // Types

// Utilities
import { defineComponent, computed } from 'vue';
import makeProps from "../../util/makeProps.mjs";
export function makeSheetProps() {
  return { ...makeBorderProps(),
    ...makeBorderRadiusProps(),
    ...makeDimensionProps(),
    ...makeElevationProps(),
    ...makePositionProps(),
    ...makeTagProps()
  };
}
export function useSheet(props, name) {
  const {
    themeClasses
  } = useTheme();
  const {
    borderClasses
  } = useBorder(props, name);
  const {
    borderRadiusClasses
  } = useBorderRadius(props);
  const {
    dimensionStyles
  } = useDimension(props);
  const {
    elevationClasses
  } = useElevation(props);
  const {
    positionClasses,
    positionStyles
  } = usePosition(props, name);
  return {
    sheetClasses: computed(() => [themeClasses.value, borderClasses.value, borderRadiusClasses.value, elevationClasses.value, positionClasses.value]),
    sheetStyles: computed(() => [dimensionStyles.value, positionStyles.value])
  };
}
export default defineComponent({
  name: 'VSheet',
  props: makeProps(makeSheetProps()),

  setup(props, {
    slots
  }) {
    const {
      sheetClasses,
      sheetStyles
    } = useSheet(props, 'v-sheet');
    return () => _createVNode(props.tag, {
      "class": ['v-sheet', sheetClasses.value],
      "style": sheetStyles.value
    }, { ...slots,
      _: 1
    }, 8, ["class", "style"]);
  }

});
//# sourceMappingURL=VSheet.mjs.map