// Utilities
import { getCurrentInstance } from 'vue';
import { useVuetify } from "../framework.mjs";
import { wrapInArray } from "./helpers.mjs"; // Types

export default function makeProps(props) {
  for (const key in props) {
    const propOptions = props[key];
    const isOptions = !(propOptions == null || Array.isArray(propOptions) || typeof propOptions === 'function');
    const type = isOptions ? propOptions.type : propOptions;
    const localDefault = isOptions ? propOptions.default : undefined;
    const wrappedDefault = generateDefault(key, localDefault, type);

    if (isOptions) {
      propOptions.default = wrappedDefault;
    } else {
      props[key] = {
        type,
        default: wrappedDefault
      };
    }
  }

  return props;
}

function generateDefault(propName, localDefault, type) {
  if (localDefault === undefined && (type === Boolean || Array.isArray(type) && type.includes(Boolean))) {
    localDefault = false;
  }

  return props => {
    var _vuetify$defaults$vm$;

    const vm = getCurrentInstance();

    if (!vm) {
      console.warn('Unable to get current component instance when generating default prop value');
      return localDefault;
    }

    if (!vm.type.name) {
      console.warn('The component is missing an explicit name, unable to generate default prop value');
      return localDefault;
    }

    const vuetify = useVuetify();
    const globalDefault = vuetify.defaults.global[propName];
    const componentDefault = (_vuetify$defaults$vm$ = vuetify.defaults[vm.type.name]) == null ? void 0 : _vuetify$defaults$vm$[propName];
    const actualDefault = typeof componentDefault !== 'undefined' ? componentDefault : typeof globalDefault !== 'undefined' ? globalDefault : localDefault;
    return isFactory(actualDefault, type) ? actualDefault(props) : actualDefault;
  };
} // Would be nice to have PropOptions here


function isFactory(val, type) {
  return typeof val === 'function' && !wrapInArray(type).includes(Function);
}
//# sourceMappingURL=makeProps.mjs.map